==> haskell-hspec-meta-2.10.5-227-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-meta
version:              2.10.5
visibility:           public
id:                   hspec-meta-2.10.5-A8s970awR1mG5tmTmHpjBp
key:                  hspec-meta-2.10.5-A8s970awR1mG5tmTmHpjBp
license:              MIT
copyright:
    (c) 2011-2022 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.

category:             Testing
abi:                  157d79b316762680bb92021d0f450b40
exposed:              True
exposed-modules:      Test.Hspec.Discover Test.Hspec.Meta
hidden-modules:
    Test.Hspec Test.Hspec.Formatters Test.Hspec.QuickCheck
    Test.Hspec.Runner GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Format
    Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Types
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
    Test.Hspec.Core.Runner.Eval
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec Test.Hspec.Core.Spec.Monad
    Test.Hspec.Core.Timer Test.Hspec.Core.Tree Test.Hspec.Core.Util
    Control.Concurrent.Async Data.Algorithm.Diff Test.HUnit
    Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal Test.HUnit.Text
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib
    Test.Hspec.Expectations.Matcher Paths_hspec_meta

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-meta-2.10.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-meta-2.10.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-meta-2.10.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-meta
hs-libraries:         HShspec-meta-2.10.5-A8s970awR1mG5tmTmHpjBp
depends:
    QuickCheck-2.14.3-C8cZng3OFrO55aPQ2PJVj0
    ansi-terminal-1.0.2-HBeoENQnxizF4CvHZENnzA array-0.5.4.0
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    clock-0.8.4-JzRzOquHqcbCVcesO697sM deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 ghc-9.4.8 ghc-boot-th-9.4.8
    quickcheck-io-0.2.0-9rpEeV9jIOUJEtRRtbqdxG
    random-1.2.1.2-DeKikqVo0OAEnmZVxkkmVK
    setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb stm-2.5.1.0 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html:         /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-meta-2.10.5-229-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-meta
version:              2.10.5
visibility:           public
id:                   hspec-meta-2.10.5-KmHLBM3vBKVHtKuJmesVcI
key:                  hspec-meta-2.10.5-KmHLBM3vBKVHtKuJmesVcI
license:              MIT
copyright:
    (c) 2011-2022 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.

category:             Testing
abi:                  0a61e1e787ca2b69c6cc421b070fd60a
exposed:              True
exposed-modules:      Test.Hspec.Discover Test.Hspec.Meta
hidden-modules:
    Test.Hspec Test.Hspec.Formatters Test.Hspec.QuickCheck
    Test.Hspec.Runner GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Format
    Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Types
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
    Test.Hspec.Core.Runner.Eval
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec Test.Hspec.Core.Spec.Monad
    Test.Hspec.Core.Timer Test.Hspec.Core.Tree Test.Hspec.Core.Util
    Control.Concurrent.Async Data.Algorithm.Diff Test.HUnit
    Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal Test.HUnit.Text
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib
    Test.Hspec.Expectations.Matcher Paths_hspec_meta

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-meta-2.10.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-meta-2.10.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-meta-2.10.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-meta
hs-libraries:         HShspec-meta-2.10.5-KmHLBM3vBKVHtKuJmesVcI
depends:
    QuickCheck-2.14.3-FGmfhk7R9XAKKHOSxyZwTx
    ansi-terminal-1.0.2-EhzJoAzi53XHL1K3CBirLP array-0.5.4.0
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    clock-0.8.4-JzRzOquHqcbCVcesO697sM deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 ghc-9.4.8 ghc-boot-th-9.4.8
    quickcheck-io-0.2.0-7zGZNsbZTNeALJLMGxgjLz
    random-1.2.1.2-7EfGGurDIwzGPzdRKPRaLg
    setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb stm-2.5.1.0 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html:         /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
